package org.acme.elytron.security.jpa;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class JpaSecurityRealmTestIT extends JpaSecurityRealmTest {
}
